@@ -188,15 +188,26 @@ class VeSyncOutlet7A(VeSyncOutlet):
             self.device_status = r.get('deviceStatus', self.device_status)
             self.details['active_time'] = r.get('activeTime', 0)
             self.details['energy'] = r.get('energy', 0)
-            power = r.get('power', '0:0')
-            power = round(float(Helpers.calculate_hex(power)), 2)
-            self.details['power'] = power
-            voltage = r.get('voltage', '0:0')
-            voltage = round(float(Helpers.calculate_hex(voltage)), 2)
-            self.details['voltage'] = voltage
+            power = r.get('power', '0')
+            self.details['power'] = self.parse_energy_detail(power)
+            voltage = r.get('voltage', 0)
+            self.details['voltage'] = self.parse_energy_detail(voltage)
         else:
             logger.debug('Unable to get %s details', self.device_name)
 
+    @staticmethod
+    def parse_energy_detail(energy):
+        """Parse energy details to be compatible with new and old firmware."""
+        try:
+            if isinstance(energy, str) and ':' in energy:
+                power = round(float(Helpers.calculate_hex(energy)), 2)
+            else:
+                power = float(energy)
+        except ValueError:
+            logger.debug('Error parsing power response - %s', energy)
+            power = 0
+        return power
+
     def get_weekly_energy(self) -> None:
         """Get 7A outlet weekly energy info and buld weekly energy dict."""
         r, _ = Helpers.call_api(
